==> kubernetes-model-resource-6.6.0-sources.jar: io/fabric8/kubernetes/api/model/resource/v1alpha1/ResourceClaimTemplateSpecFluent.java <==
package io.fabric8.kubernetes.api.model.resource.v1alpha1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ResourceClaimTemplateSpecFluent<A extends ResourceClaimTemplateSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public ResourceClaimTemplateSpecFluent.MetadataNested<A> withNewMetadata();
  public ResourceClaimTemplateSpecFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public ResourceClaimTemplateSpecFluent.MetadataNested<A> editMetadata();
  public ResourceClaimTemplateSpecFluent.MetadataNested<A> editOrNewMetadata();
  public ResourceClaimTemplateSpecFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public ResourceClaimSpec getSpec();
  public ResourceClaimSpec buildSpec();
  public A withSpec(ResourceClaimSpec spec);
  public Boolean hasSpec();
  public ResourceClaimTemplateSpecFluent.SpecNested<A> withNewSpec();
  public ResourceClaimTemplateSpecFluent.SpecNested<A> withNewSpecLike(ResourceClaimSpec item);
  public ResourceClaimTemplateSpecFluent.SpecNested<A> editSpec();
  public ResourceClaimTemplateSpecFluent.SpecNested<A> editOrNewSpec();
  public ResourceClaimTemplateSpecFluent.SpecNested<A> editOrNewSpecLike(ResourceClaimSpec item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<ResourceClaimTemplateSpecFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface SpecNested<N> extends Nested<N>,ResourceClaimSpecFluent<ResourceClaimTemplateSpecFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  
}

==> kubernetes-model-resource-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/resource/v1alpha1/ResourceClaimTemplateSpecFluent.java <==
package io.fabric8.kubernetes.api.model.resource.v1alpha1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ResourceClaimTemplateSpecFluent<A extends ResourceClaimTemplateSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public ResourceClaimTemplateSpecFluent.MetadataNested<A> withNewMetadata();
  public ResourceClaimTemplateSpecFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public ResourceClaimTemplateSpecFluent.MetadataNested<A> editMetadata();
  public ResourceClaimTemplateSpecFluent.MetadataNested<A> editOrNewMetadata();
  public ResourceClaimTemplateSpecFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public ResourceClaimSpec getSpec();
  public ResourceClaimSpec buildSpec();
  public A withSpec(ResourceClaimSpec spec);
  public Boolean hasSpec();
  public ResourceClaimTemplateSpecFluent.SpecNested<A> withNewSpec();
  public ResourceClaimTemplateSpecFluent.SpecNested<A> withNewSpecLike(ResourceClaimSpec item);
  public ResourceClaimTemplateSpecFluent.SpecNested<A> editSpec();
  public ResourceClaimTemplateSpecFluent.SpecNested<A> editOrNewSpec();
  public ResourceClaimTemplateSpecFluent.SpecNested<A> editOrNewSpecLike(ResourceClaimSpec item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<ResourceClaimTemplateSpecFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface SpecNested<N> extends Nested<N>,ResourceClaimSpecFluent<ResourceClaimTemplateSpecFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  
}
